require 'time'

class ReadDir

  attr_reader   :dir, :term, :articles
  attr_accessor :count

  def initialize(dir)
    @articles = []
    @dir      = dir
  end

  def process_file(name)
    File.open(name) do |f|
      @articles << f.readlines
    end
  end

  def process_directory(dir)
    dirs = dir.entries
    dirs.delete_if { |entry| entry =~ /^\./ }
    dirs.delete_if { |entry| entry =~ /\.rb$/ }
    dirs.each { |entry| 
      full_path = File.join(dir.path, entry)
      if File.directory?(full_path)
        process_directory(Dir.new(full_path))
      else
        process_file(full_path)
      end
    }
  end

  def read
    process_directory(Dir.new(@dir))
  end

end

current_dir = `pwd`.chomp

puts "Reading in the contents rooted at #{current_dir}"

start = Time.new

reader = ReadDir.new(current_dir)
reader.read

finish = Time.new

puts "Done. Read in #{reader.articles.size} articles in #{finish-start} secs."
puts "Searching for term 'iran'."

articles = reader.articles

count = 0

start = Time.new
articles.each { |lines|
  lines = lines.find_all { |line| line.include?("iran") }
  if lines.size > 0
    count += 1
  end
}
finish = Time.new
puts "Finshed in #{finish-start} seconds. Term occurs in #{count} articles."
